<?php

namespace Drupal\user_hash\Tests;

use Drupal\simpletest\WebTestBase;

/**
 * Test user hash generation.
 * 
 * @group user_hash
 * 
 * @requires user
 */
class UserHashGenerationTest extends WebTestBase {

  /**
   * A user with permission to administrate user hashes.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $adminUser;
  
  /**
   * A user with the 'access user profiles' permission.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $baseUser1;

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = array('system', 'views', 'user', 'user_hash');

  /**
   * Set up test environment.
   */
  protected function setUp() {
    parent::setUp();

    $this->adminUser = $this->drupalCreateUser(array(
      'administer site configuration',
      'access administration pages',
      'administer users',
      'administer account settings',
      'access user profiles',
    ));
    $this->baseUser1 = $this->drupalCreateUser(array(
      'access user profiles',
    ));
  }

  /**
   * Test user hash generation.
   */
  public function testUserHashGeneration() {
    $this->drupalLogin($this->adminUser);

    $edit = array(
      'action' => 'user_generate_user_hash_action',
      'user_bulk_form[1]' => TRUE,
    );
    $path = 'admin/people';
    $this->drupalPostForm($path, $edit, t('Apply to selected items'), array(), array(), 'views-form-user-admin-people-page-1');
    $this->assertText('Generate hash for', 'Hash generated.');
    $this->drupalGet('user/' . $this->adminUser->id());
    $this->assertResponse(200);
    $this->assertPattern('/' . t('Hash') . '<\/h4> [0-9A-Fa-f]{64}/', 'User hash displayed on profile.');
    
    $this->drupalLogout();
    $this->drupalLogin($this->baseUser1);
    $this->drupalGet('user/' . $this->adminUser->id());
    $this->assertResponse(200);
    $this->assertNoPattern('/' . t('Hash') . '<\/h4> [0-9A-Fa-f]{64}/', 'User hash not displayed on profile.');

    $this->drupalLogout();
    $this->drupalLogin($this->adminUser);
    $edit = array(
      'action' => 'user_delete_user_hash_action',
      'user_bulk_form[1]' => TRUE,
    );
    $path = 'admin/people';
    $this->drupalPostForm($path, $edit, t('Apply to selected items'), array(), array(), 'views-form-user-admin-people-page-1');
    $this->assertText('Delete hash from', 'Hash deleted.');
    $this->drupalGet('user/' . $this->adminUser->id());
    $this->assertResponse(200);
    $this->assertNoPattern('/' . t('Hash') . '<\/h4> [0-9A-Fa-f]{64}/', 'User hash not displayed on profile.');
  }

}
